@@ -198,8 +198,8 @@ def unpack_key( ) :
     #s_log.write(endpoint_key)
 
     if( not endpoint_key ) :
-        endpoint_key="*|*|*"
-        s_log.write( "default endpoint_key" )
+        endpoint_key = "*|*|*"
+        #s_log.write( "default endpoint_key" )
         #return
 
     ########################################################
@@ -226,9 +226,9 @@ def unpack_key( ) :
     if( ( key_parts[ 1 ] != "*" ) ) :
         url = key_parts[ 1 ]
         if( url[ 0:4 ] != "http" ) : url = "https://" + url
-        purl = s_util.url_parse(url)
-        if(purl.port==None):
-            url=url+":443"
+        purl = s_util.url_parse( url )
+        if( purl.port == None ) :
+            url = url + ":443"
         #set_key_alt( "endpoint/url" , url )
         set_key( "endpoint/url" , url )
 
