@@ -669,6 +669,10 @@ def files_dict2json( fp , fdict ) :
 
     return( True )
 
+def file_getjson2dict( fp ) :
+    fc = files_getcontent( fp )
+    return( s_util.json_loads(fc))
+
 def files_getcontent( fp ) :
     f = files_read( fp )
     if not f :
@@ -676,6 +680,8 @@ def files_getcontent( fp ) :
         return( False )
     return( f[ "fc" ] )
 
+
+
 def files_readallmeta( ) :
 
     sql = "SELECT fp,fs,fh,fm FROM files" 
