@@ -306,16 +306,14 @@ def job_get( queues_list = False ) :
                     "X-Omni-Action": "job_get" ,
                 }
 
-
-
     if(queues_list==False):
         env_queue=s_util.environ_get("_CONTAINER_LOCAL_APPQUEUE") ;
         if(env_queue):
             if not env_queue.endswith( "_LOCAL_APPQUEUE_" ) : 
                 #s_log.write("FOUND _CONTAINER_LOCAL_APPQUEUE "+env_queue)
                 headers["X-Omni-Queue"]=env_queue
-        else:
-            s_log.write( "NOT FOUND _CONTAINER_LOCAL_APPQUEUE" )
+        #else:
+        #    s_log.write( "NOT FOUND _CONTAINER_LOCAL_APPQUEUE" )
     else:
         headers[ "X-Omni-Queue" ] = "," . join( queues_list )
 
