@@ -273,7 +273,7 @@ def printexit( msg ) :
     sys.exit( )
 
 
-def printexception( e = False ) :
+def LEGACYprintexception( e = False ) :
     if e :
         print( "EXCEPTION" + str( e ) )
     etype , value, tb = sys.exc_info( )
@@ -296,6 +296,13 @@ def full_stack():
     return stackstr
 
 
+def print_exception():
+    etype, value, tb = sys.exc_info()
+    info, error = format_exception(etype, value, tb)[-2:]
+    print(f'Exception in:\n{info}\n{error}')
+
+
+
 heartbeat_last = 0
 def heartbeat( t = 600 ) :
     global heartbeat_last
@@ -572,6 +579,13 @@ def datetime_nowutcstr( td = 0 ) :
 
     return( d.strftime( "%Y-%m-%dT%H:%M:%S" ) )
 
+
+def datetime_filestamp( td = 0 ) :
+
+    d = datetime.utcnow( ) + timedelta( seconds = td)
+
+    return( d.strftime( "%Y%m%d%H%M%S" ) )
+
 def datetime_now_db( td = 0 ) :
 
     d = datetime.now( ) + timedelta( seconds = td)
@@ -680,6 +694,10 @@ def file_rm( fp ) :
     os.remove( fp )
     return( True )
 
+
+def file_copy( fps , fpt ) :
+    shutil.copyfile(fps,fpt)
+
 def path_stem( p ) :
     fn = Path( p ).stem
     return( fn )
