@@ -20,7 +20,7 @@ from . import s_log , s_config , s_net , s_util , s_db , s_cache , s_cleanup
 
 #####################################################################
 
-#s_log.write( "    ####    ####    ####    ####\n" )
+s_log.write( "    ####    ####    ####    ####\n" )
 
 #####################################################################
 
@@ -77,80 +77,6 @@ def log_lap( ) :
 def heartbeat( t = 60 ) :
     return( s_util.heartbeat( t ) )
 
-def server( runner , debug_errorprexit = False ) :
-
-    s_log.write( "SERVER START" )
-
-    while True :
-
-        s_log.write( "SERVER LOOP" )
-
-        heartbeat( )
-
-        #####################################################
-
-        try :
-            flag_jobget = s_net.job_get( )
-        except Exception as e :
-            s_log.write( "Exception job_get" )
-            s_util.printexception( )
-            # FIXME TODO add flags to server
-            if debug_errorprexit : prexit( "EXCEPTION job_get" )
-            print( "Exception job_get" )
-            continue
-            #sys.exit( 99 )
-
-        #####################################################
-        
-        if flag_jobget == False :
-
-            #s_config.get_key( "endpoint/url" ) 
-            s_log.write( "ERROR False job_get" )
-            if debug_errorprexit : prexit( "ERROR False job_get" )
-            print( "ERROR False job_get" )
-            s_util.sleep( 10 )
-            continue
-
-        if flag_jobget == None :
-            continue
-
-        #####################################################
-        #context =  s_config.get_key( "header_context" )
-        #s_log.write( context )
-        #qparams = context[ "qparams" ]
-        #####################################################
-
-
-        #if( not s_util.proc_setup( ) ) :
-        #    continue
-
-        #####################################################
-
-        #s_util.proc_run( )
-
-        #####################################################
-
-        #s_util.proc_storage( )
-        #s_util.proc_teardown( )
-
-        #####################################################
-
-        #config = { 
-        #    "_env" : s_util.container_appenvstatic_get( )
-        #}
-        runner_output = runner( )
-        s_db.meta_create( "_runner_exitflag" , runner_output )
-
-        s_net.job_set( )
-
-        #####################################################
-
-        s_log.write( "OK" )
-
-    s_log.write( "SERVER END" )
-
-
-
 #####################################################################################################
 runner_omnibus_ctime = 0
 # Required to make module name scope available in function for importlib
@@ -244,7 +170,7 @@ def runner_omnibus( path_runner ) :
             # This could change if runner does a sapi request!?!?
             jid_omnibus = s_config.get_key( "jid" )
 
-            s_log.write( "process start" )
+            #s_log.write( "process start" )
             prc1 = multiprocessing.Process( target = _sapi_runner_omnibus._entrypoint , daemon = True )
             prc1.start( )
             prc_starttime = s_util.uptime( )
@@ -270,7 +196,7 @@ def runner_omnibus( path_runner ) :
             prc1.join( )
             # -9 when kill, 1 when exception/error..? 0 is OK
             runner_exitcode = prc1.exitcode
-            s_log.write( "process end" )
+            #s_log.write( "process end" )
 
             ########################################################
 
@@ -286,7 +212,7 @@ def runner_omnibus( path_runner ) :
             continue
 
         #runner_exitcode = _sapi_runner_omnibus._entrypoint( )
-        s_log.write( "runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
+        #s_log.write( "runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
 
         #####################################################
 
@@ -295,66 +221,7 @@ def runner_omnibus( path_runner ) :
 
         #####################################################
 
-        s_log.write( "OK" )
-
-#####################################################################################################
-runner_internal_ctime = 0
-# Required to make module name scope available in function for importlib
-_sapi_runner_internal = None
-def sapirunner_internal_reloadifchanged( path_runner ) :
-    global runner_internal_ctime
-    try :
-        if( s_util.file_changed( path_runner , runner_internal_ctime ) ) :
-            runner_internal_ctime = s_util.file_ctime( path_runner )
-            importlib.reload( _sapi_runner_internal )
-            s_log.write( "path_runner RELOAD" , consoleprint = True )
-            s_util.sleep( 3 )
-
-    except Exception as e :
-        s_log.write( "ERROR sapirunner_internal_reloadifchanged " + str( e ) , consoleprint = True )
-        s_util.sleep( 3 )
-        return( False )
-
-    return( True )
-
-
-def runner_internal( path_runner ) :
-
-    # Required to make module name scope available in function for importlib
-    global _sapi_runner_internal
-
-    s_log.write( "RUNNER_internal START " + path_runner )
-
-    if( not s_util.sys_path_append_fp( path_runner ) ) :
-        s_log.write( "ERROR NOT FOUND " + path_runner , consoleprint = True )
-        prexit( "ERR" )
-
-    import _sapi_runner_internal
-
-    global runner_internal_ctime
-    runner_internal_ctime = s_util.file_ctime( path_runner )
-
-    while True :
-
-        s_util.sleep( 0.1 )
-
-        heartbeat( )
-
-        #####################################################
-        if( not sapirunner_internal_reloadifchanged( path_runner ) ) : continue
-        #####################################################
-
-        try :
-            runner_exitcode = _sapi_runner_internal._entrypoint( )
-            if( runner_exitcode > 0 ) :
-                s_log.write( "ERROR _sapi_runner_internal runner_exitcode " + str( runner_exitcode ) , consoleprint = True )
-                continue
-        except Exception as e :
-            s_log.write( "ERROR _sapi_runner_internal Exception " + str( e ) , consoleprint = True )
-            s_util.sleep( 3 )
-            continue
-
-        #####################################################
+        #s_log.write( "OK" )
 
 def omnibus_ping( ) :
     run( {
